# ABSTRACT: An Autobox Implementation for Perl 5
package Data::Object::Autobox;

use 5.10.0;

use strict;
use warnings;

our $VERSION = '0.01'; # VERSION

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Object::Autobox - An Autobox Implementation for Perl 5

=head1 VERSION

version 0.01

=head1 SYNOPSIS

    use Data::Object::Autobox;

=head1 DESCRIPTION

Data::Object::Autobox implements autoboxing via L<Data::Object> to provide
L<boxing|http://en.wikipedia.org/wiki/Object_type_(object-oriented_programming)>
for native Perl 5 data types.

=head1 AUTHOR

Al Newkirk <anewkirk@ana.io>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Al Newkirk.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
